//!/////////////////////////////////////////////////////////////////////////
/// adc.c                                                                 //
///                                                                       //
/// Version:     0.3                                                      //
/// Date:        11/19/2009                                               //
/// Author:      Michael Skutek (michael@skutek.de)                       //
///                                                                       //
/// Description: A/D conversion function (single conversion)              //
///                                                                       //
/// Platform:    AVR ATmega (tested on ATMega16)                          //
///                                                                       //
/// Include Files:                                                        //
///              avr/io.h:             port accessing (part of avr-gcc)   //
///              port_definitions.h:   definition of output ports         //
///              adc.h:                defintions (e.g. return values)    //
///                                                                       //
///                                                                       //
/// This program is free software: you can redistribute it and/or modify  //
/// it under the terms of the GNU Lesser General Public License as        //
/// published by the Free Software Foundation, either version 3 of the    //
/// License, or (at your option) any later version.                       //
///                                                                       //
/// This program is distributed in the hope that it will be useful,       //
/// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          //
/// GNU Lesser General Public License for more details.                   //
///                                                                       //
/// You should have received a copy of the GNU Lesser General Public      //
/// License along with this program. If not, see                          //
/// <http://www.gnu.org/licenses/>.                                       //
//!/////////////////////////////////////////////////////////////////////////


#ifndef ADC_H_INCLUDED
#define ADC_H_INCLUDED


///definitions for A/D conversion

#define ADC_UNKNOWN_ERROR         0xffffffff            //error value for wrong A/D conversion (for unknown reason)
#define ADC_PIN_ERROR             0xfffffffe            //wrong pin configuration for A/D conversion
#define ADC_FREQUENCY_ERROR       0xfffffffd            //wrong sample frequency requested
#define ADC_NUMBERCYCLES_ERROR    0xfffffffc            //wrong number of conversion cycles

#define MAX_NUMBER_ADC_CYCLES    838                    //number of possible single shot cycles (overflow avoidance)
#define MIN_ADC_FREQUENCY         50                    //lowest ADC sampling frequency [kHz]
#define MAX_ADC_FREQUENCY        200                    //highest ADC sampling frequency [kHz]

#define ADC_REF_AREF             0x0                    //Reference Voltage: AREF, internal VREF turned off
#define ADC_REF_AVCC             0x1                    //Reference Voltage: AVCC, with external capacitor at AREF pin
#define ADC_REF_VREF             0x3                    //Reference Voltage: internal VREF (2,56 V) with external capacitor at AREF pin



///function prototypes
uint32_t single_adc_read(uint8_t vref_reg, uint16_t vref_val,
                          uint16_t number_cycles, uint16_t min_freq);
void adc_pin_init(void);


#endif // ADC_H_INCLUDED
