//!/////////////////////////////////////////////////////////////////////////
/// babyphone_receiver.h                                                  //
///                                                                       //
/// Version:     0.5                                                      //
/// Date:        03/04/2013                                               //
/// Author:      Michael Skutek (michael@skutek.de)                       //
///                                                                       //
/// Description: Global definitions for Babyphone Receiver                //
///                                                                       //
/// Platform:    AVR ATmega (tested on ATmega16)                          //
///                                                                       //
///                                                                       //
///                                                                       //
/// This program is free software: you can redistribute it and/or modify  //
/// it under the terms of the GNU Lesser General Public License as        //
/// published by the Free Software Foundation, either version 3 of the    //
/// License, or (at your option) any later version.                       //
///                                                                       //
/// This program is distributed in the hope that it will be useful,       //
/// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          //
/// GNU Lesser General Public License for more details.                   //
///                                                                       //
/// You should have received a copy of the GNU Lesser General Public      //
/// License along with this program. If not, see                          //
/// <http://www.gnu.org/licenses/>.                                       //
//!/////////////////////////////////////////////////////////////////////////


#ifndef BABYFONE_RECEIVER_H_INCLUDED
#define BABYFONE_RECEIVER_H_INCLUDED


///general definitions
#ifndef TRUE
#define TRUE                             1
#endif
#ifndef FALSE
#define FALSE                            0
#endif


#define BABYFONE_RECEIVER_VERSION      0.5




///functional definitions
#define AD_SAMPLE_CYCLE_TIME            50           //cycle time for A/D conversion cycles [ms]

#define TRANSMIT_COUNTER_CYCLES        200           //number of A/D samples which has to be reached to send via RFM12
                                                     //during normal operation (no baby detected)

#define DETECTION_BUFFER_LENGTH          5           //length of detection buffer (number of A/D cycles used for detection)
#define DETECTION_BUFFER_TRESHOLD      650           //treshold for accoustical baby detection output [mV]


#define SECOND_CTR_VALUE               124           //compare value for timer interrupt
#define SECOND_COMPLETED_MAX           124           //for 16 MHz, clock prescaler 1024 and CTR 124: 125 cycles per second

#define MAX_SYNC_TIME                   60           //maximum time for synchronization lost detection [s]

#define BACKLIGHT_ON_TIME1               5           //number of seconds for backlight on (user request) [s]
#define BACKLIGHT_ON_TIME2              30           //number of seconds for backlight on (baby detected) [s]

#define BUTTON_MUTE_TIME                 3           //number of seconds of button pressing for mute [s]
#define BUZZER_MUTE_TIME               600           //number of seconds for buzzer mute [s]

#define RFM12_TXBUFFER_LENGTH           16           //length of transmit buffer
#define RFM12_RXBUFFER_LENGTH           16           //length of receive buffer
#define RFM12_RXPACKET_LENGTH           10           //length of a complete rx packet
#define RFM12_CHECKSUM_LENGTH            4           //length of checksum [bytes]
#define RFM12_CHECKSUM_BYTE3_ID          5           //ID of checksum byte 3
#define RFM12_CHECKSUM_BYTE2_ID          6           //ID of checksum byte 2
#define RFM12_CHECKSUM_BYTE1_ID          7           //ID of checksum byte 1
#define RFM12_CHECKSUM_BYTE0_ID          8           //ID of checksum byte 0
#define RFM12_BABYDETECT_BYTE_ID         4           //ID of "baby detect" byte
#define RFM12_DATA_LENGTH                5           //length of data [bytes]


///Command Error Messages

//USART
#define UART_NO_ERROR_MSG                0
#define UART_UNKNOWN_COMMAND_MSG         1
#define UART_RCV_BUFFER_OVERFLOW_MSG     2


///Command Info Messages

//USART
#define UART_NO_INFO_MSG                 0
#define UART_BABY_DETECT_MSG             1
#define UART_ALIVE_MSG                   2
#define UART_RCV_BUFFER_RESET_MSG       16
#define UART_LINK_ERROR_MSG             17




///prototypes

int main(void);




#endif // BABYFONE_RECEIVER_H_INCLUDED
