//!/////////////////////////////////////////////////////////////////////////
/// glcd_bitmaps.h                                                        //
///                                                                       //
/// Version:     0.6                                                      //
/// Date:        04/16/2010                                               //
/// Author:      Michael Skutek (michael@skutek.de)                       //
///                                                                       //
/// Description: 8 Bit Interface to GLCD displays with 128x64 dots        //
///              and KS0108 Controller.                                   //
///                                                                       //
/// Platform:    AVR ATmega (tested on ATmega16)                          //
///                                                                       //
/// Include Files:                                                        //
///              avr/io.h:             port accessing (part of avr-gcc)   //
///              util/delay.h:         time delays (part of avr-gcc)      //
///              port_definitions.h:   definition of output ports         //
///              glcd.h:               definitions and display setup      //
///              glcd_characters.h:    definitions for font(s)            //
///              glcd_bitmaps.h:       definitions for bitmaps            //
///                                                                       //
///                                                                       //
/// This program is free software: you can redistribute it and/or modify  //
/// it under the terms of the GNU Lesser General Public License as        //
/// published by the Free Software Foundation, either version 3 of the    //
/// License, or (at your option) any later version.                       //
///                                                                       //
/// This program is distributed in the hope that it will be useful,       //
/// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          //
/// GNU Lesser General Public License for more details.                   //
///                                                                       //
/// You should have received a copy of the GNU Lesser General Public      //
/// License along with this program. If not, see                          //
/// <http://www.gnu.org/licenses/>.                                       //
//!/////////////////////////////////////////////////////////////////////////



#ifndef GLCD_BITMAPS_H_INCLUDED
#define GLCD_BITMAPS_H_INCLUDED



#define smiley2_width 68
#define smiley2_height 47
static const unsigned char smiley2_bits[] PROGMEM = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0xf0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xff, 0x7f,
   0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x00, 0x80, 0xff,
   0x0f, 0x00, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0x3f, 0x00, 0x00, 0xe0,
   0x7f, 0x00, 0x00, 0x00, 0xfc, 0x0f, 0x00, 0x00, 0x00, 0xff, 0x01, 0x00,
   0x00, 0xfe, 0x01, 0x00, 0x00, 0x00, 0xfc, 0x07, 0x00, 0x00, 0x7f, 0x00,
   0x00, 0x00, 0x00, 0xe0, 0x0f, 0x00, 0xc0, 0x1f, 0x70, 0x00, 0x00, 0xe0,
   0x80, 0x1f, 0x00, 0xc0, 0x0f, 0xfc, 0x03, 0x00, 0xfc, 0x07, 0x3f, 0x00,
   0xe0, 0x07, 0xff, 0x0f, 0x00, 0xff, 0x1f, 0x7e, 0x00, 0xf0, 0x01, 0xff,
   0x0f, 0x00, 0xff, 0x1f, 0xfc, 0x00, 0xf8, 0x80, 0xff, 0x1f, 0x80, 0xff,
   0x3f, 0xf8, 0x01, 0x78, 0x80, 0xff, 0x1f, 0x80, 0xff, 0x3f, 0xf0, 0x03,
   0x3c, 0xc0, 0xff, 0x3f, 0xc0, 0xff, 0x7f, 0xe0, 0x03, 0x3c, 0xc0, 0xff,
   0x3f, 0xc0, 0xff, 0x7f, 0xc0, 0x07, 0x3e, 0xc0, 0x7f, 0x3c, 0xc0, 0xe7,
   0x7f, 0xc0, 0x07, 0x3e, 0x80, 0x3f, 0x10, 0x80, 0x81, 0x3f, 0x80, 0x07,
   0x1e, 0x80, 0x3f, 0x10, 0x80, 0x81, 0x3f, 0x80, 0x07, 0x1e, 0x00, 0x7f,
   0x08, 0x00, 0xc3, 0x1f, 0x80, 0x07, 0x1e, 0x00, 0x7f, 0x0c, 0x00, 0xe7,
   0x1f, 0x80, 0x07, 0x0f, 0x00, 0xfc, 0x03, 0x00, 0xfc, 0x07, 0x80, 0x07,
   0x1e, 0x00, 0x70, 0x00, 0x00, 0xe0, 0x00, 0x80, 0x07, 0x1e, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x80, 0x07, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07,
   0x3e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x3c, 0x00, 0x00,
   0x00, 0x00, 0x80, 0x00, 0xc0, 0x07, 0x3c, 0x00, 0x1c, 0x00, 0x00, 0xc0,
   0x01, 0xe0, 0x03, 0x78, 0x00, 0x7c, 0x00, 0x00, 0xf0, 0x03, 0xf0, 0x03,
   0xf8, 0x00, 0xfe, 0x01, 0x00, 0xfc, 0x03, 0xf8, 0x01, 0xf0, 0x01, 0xf8,
   0x03, 0x80, 0xff, 0x01, 0xfc, 0x00, 0xe0, 0x07, 0xe0, 0xff, 0xff, 0xff,
   0x00, 0x7e, 0x00, 0xc0, 0x0f, 0xc0, 0xff, 0xff, 0x3f, 0x00, 0x3f, 0x00,
   0xc0, 0x1f, 0x00, 0xff, 0xff, 0x07, 0x80, 0x1f, 0x00, 0x80, 0x7f, 0x00,
   0xfe, 0xff, 0x00, 0xe0, 0x0f, 0x00, 0x00, 0xff, 0x00, 0xe0, 0x1f, 0x00,
   0xf8, 0x07, 0x00, 0x00, 0xfe, 0x01, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00,
   0x00, 0xfc, 0x0f, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0xe0, 0x3f,
   0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0xff,
   0x1f, 0x00, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00,
   0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0,
   0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00 };



#define smiley3_width 68
#define smiley3_height 47
static const unsigned char smiley3_bits[] PROGMEM = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0xf0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xff, 0x7f,
   0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x00, 0x80, 0xff,
   0x0f, 0x00, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0x3f, 0x00, 0x00, 0xe0,
   0x7f, 0x00, 0x00, 0x00, 0xfc, 0x0f, 0x00, 0x00, 0x00, 0xff, 0x01, 0x00,
   0x00, 0xfe, 0x01, 0x00, 0x00, 0x00, 0xfc, 0x07, 0x00, 0x00, 0x7f, 0x00,
   0x00, 0x00, 0x00, 0xe0, 0x0f, 0x00, 0xc0, 0x1f, 0x70, 0x00, 0x00, 0xe0,
   0x80, 0x1f, 0x00, 0xc0, 0x0f, 0xfc, 0x03, 0x00, 0xfc, 0x07, 0x3f, 0x00,
   0xe0, 0x07, 0xff, 0x0f, 0x00, 0xff, 0x1f, 0x7e, 0x00, 0xf0, 0x01, 0xff,
   0x0f, 0x00, 0xff, 0x1f, 0xfc, 0x00, 0xf8, 0x80, 0xff, 0x1f, 0x80, 0xff,
   0x3f, 0xf8, 0x01, 0x78, 0x80, 0xff, 0x1f, 0x80, 0xff, 0x3f, 0xf0, 0x03,
   0x3c, 0xc0, 0xff, 0x3f, 0xc0, 0xff, 0x7f, 0xe0, 0x03, 0x3c, 0xc0, 0xff,
   0x3f, 0xc0, 0xff, 0x7f, 0xc0, 0x07, 0x3e, 0xc0, 0x7f, 0x3c, 0xc0, 0xe7,
   0x7f, 0xc0, 0x07, 0x3e, 0x80, 0x3f, 0x10, 0x80, 0x81, 0x3f, 0x80, 0x07,
   0x1e, 0x80, 0x3f, 0x10, 0x80, 0x81, 0x3f, 0x80, 0x07, 0x1e, 0x00, 0x7f,
   0x08, 0x00, 0xc3, 0x1f, 0x80, 0x07, 0x1e, 0x00, 0x7f, 0x0c, 0x00, 0xe7,
   0x1f, 0x80, 0x07, 0x0f, 0x00, 0xfc, 0x03, 0x00, 0xfc, 0x07, 0x80, 0x07,
   0x1e, 0x00, 0x70, 0x00, 0x00, 0xe0, 0x00, 0x80, 0x07, 0x1e, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x80, 0x07, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07,
   0x3e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x3c, 0x00, 0x00,
   0xe0, 0xff, 0x00, 0x00, 0xc0, 0x07, 0x3c, 0x00, 0x00, 0xfe, 0xff, 0x07,
   0x00, 0xe0, 0x03, 0x78, 0x00, 0x80, 0xff, 0xff, 0x3f, 0x00, 0xf0, 0x03,
   0xf8, 0x00, 0xe0, 0xff, 0xff, 0x7f, 0x00, 0xf8, 0x01, 0xf0, 0x01, 0xf0,
   0x3f, 0x80, 0xff, 0x00, 0xfc, 0x00, 0xe0, 0x07, 0xf8, 0x03, 0x00, 0xfc,
   0x03, 0x7e, 0x00, 0xc0, 0x0f, 0x7e, 0x00, 0x00, 0xf0, 0x07, 0x3f, 0x00,
   0xc0, 0x1f, 0x3c, 0x00, 0x00, 0xc0, 0x81, 0x1f, 0x00, 0x80, 0x7f, 0x18,
   0x00, 0x00, 0x80, 0xe1, 0x0f, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00,
   0xf8, 0x07, 0x00, 0x00, 0xfe, 0x01, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00,
   0x00, 0xfc, 0x0f, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0xe0, 0x3f,
   0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0xff,
   0x1f, 0x00, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00,
   0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0,
   0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00 };



#define smiley4_width 68
#define smiley4_height 47
static const unsigned char smiley4_bits[] PROGMEM = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0xf0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xff, 0x7f,
   0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x00, 0x80, 0xff,
   0x0f, 0x00, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0x3f, 0x00, 0x00, 0xe0,
   0x7f, 0x00, 0x00, 0x00, 0xfc, 0x0f, 0x00, 0x00, 0x00, 0xff, 0x01, 0x00,
   0x00, 0xfe, 0x01, 0x00, 0x00, 0x00, 0xfc, 0x07, 0x00, 0x00, 0x7f, 0x00,
   0x00, 0x00, 0x00, 0xe0, 0x0f, 0x00, 0xc0, 0x1f, 0x70, 0x00, 0x00, 0xe0,
   0x80, 0x1f, 0x00, 0xc0, 0x0f, 0xfc, 0x03, 0x00, 0xfc, 0x07, 0x3f, 0x00,
   0xe0, 0x07, 0xff, 0x0f, 0x00, 0xff, 0x1f, 0x7e, 0x00, 0xf0, 0x01, 0xff,
   0x0f, 0x00, 0xff, 0x1f, 0xfc, 0x00, 0xf8, 0x80, 0xff, 0x1f, 0x80, 0xff,
   0x3f, 0xf8, 0x01, 0x78, 0x80, 0xff, 0x1f, 0x80, 0xff, 0x3f, 0xf0, 0x03,
   0x3c, 0xc0, 0xff, 0x3f, 0xc0, 0xff, 0x7f, 0xe0, 0x03, 0x3c, 0xc0, 0xff,
   0x3f, 0xc0, 0xff, 0x7f, 0xc0, 0x07, 0x3e, 0xc0, 0x7f, 0x3c, 0xc0, 0xe7,
   0x7f, 0xc0, 0x07, 0x3e, 0x80, 0x3f, 0x10, 0x80, 0x81, 0x3f, 0x80, 0x07,
   0x1e, 0x80, 0x3f, 0x10, 0x80, 0x81, 0x3f, 0x80, 0x07, 0x1e, 0x00, 0x7f,
   0x08, 0x00, 0xc3, 0x1f, 0x80, 0x07, 0x1e, 0x00, 0x7f, 0x0c, 0x00, 0xe7,
   0x1f, 0x80, 0x07, 0x0f, 0x00, 0xfc, 0x03, 0x00, 0xfc, 0x07, 0x80, 0x07,
   0x1e, 0x00, 0x70, 0x00, 0x00, 0xe0, 0x00, 0x80, 0x07, 0x1e, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x80, 0x07, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07,
   0x3e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x3c, 0x00, 0xfe,
   0xff, 0xff, 0xff, 0x07, 0xc0, 0x07, 0x3c, 0x00, 0xfe, 0xff, 0xff, 0xff,
   0x07, 0xe0, 0x03, 0x78, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0xf0, 0x03,
   0xf8, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0xf8, 0x01, 0xf0, 0x01, 0xfe,
   0xff, 0xff, 0xff, 0x07, 0xfc, 0x00, 0xe0, 0x07, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x7e, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00,
   0xc0, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x80, 0x1f, 0x00, 0x80, 0x7f, 0x00,
   0x00, 0x00, 0x00, 0xe0, 0x0f, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00,
   0xf8, 0x07, 0x00, 0x00, 0xfe, 0x01, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00,
   0x00, 0xfc, 0x0f, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0xe0, 0x3f,
   0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0xff,
   0x1f, 0x00, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00,
   0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0,
   0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00 };





/// diagram bitmap - can be shown with "glcd_show_xbm()"
/// a better way: using "glcd_shwo_diagram()"

#define glcd_diagramm_width 128
#define glcd_diagramm_height 64
static const unsigned char glcd_diagramm_bits[] PROGMEM = {
   0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff };



#endif // GLCD_BITMAPS_H_INCLUDED
