//!/////////////////////////////////////////////////////////////////////////
/// port_definitions.h                                                    //
///                                                                       //
/// Version:     0.8                                                      //
/// Date:        01/09/2010                                               //
/// Author:      Michael Skutek (michael@skutek.de)                       //
///                                                                       //
/// Description: Port Settings (Definitions, Association)                 //
///                                                                       //
/// Platform:    AVR ATmega (tested on ATmega16)                          //
///                                                                       //
///                                                                       //
/// This program is free software: you can redistribute it and/or modify  //
/// it under the terms of the GNU Lesser General Public License as        //
/// published by the Free Software Foundation, either version 3 of the    //
/// License, or (at your option) any later version.                       //
///                                                                       //
/// This program is distributed in the hope that it will be useful,       //
/// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          //
/// GNU Lesser General Public License for more details.                   //
///                                                                       //
/// You should have received a copy of the GNU Lesser General Public      //
/// License along with this program. If not, see                          //
/// <http://www.gnu.org/licenses/>.                                       //
//!/////////////////////////////////////////////////////////////////////////


#ifndef PORT_DEFINITIONS_H_INCLUDED
#define PORT_DEFINITIONS_H_INCLUDED




///Typical Display Pinout (WITHOUT WARRANTY - READ DOCUMENTATION!):

//  Symbol              Pin No.         Description
//
//    Vss                 1               Ground
//    Vdd                 2               Supply Voltage for Logic
//    Vo                  3               Supply Voltage for LCD
//    RS                  4               Register Select (RS=0: Instruction Register, RS=1: Data Register)
//    R/W                 5               Read/Write (R/W=0: write, R/W=1: read)
//    E                   6               Enable
//    D0 to D7          7 to 14           Bi-directional Data Bus
//    BL-                15               Backlight supply terminal (Anode)
//    BL+                16               Backlight supply terminal (Cathode)




///Pin Settings

//LCD
#define LCD_PORT                     PORTC          //Controller Port for LCD Output
#define LCD_DDR                       DDRC          //DDR Register of Controller Port for LCD Output
#define LCD_RS                         PC0          //Pin for RS (Register Select)
#define LCD_RW                         PC6          //Pin for R/W (Read/Write)
#define LCD_EN                         PC1          //Pin for E (Enable)

#define LCD_BACKLIGHT                  PC7          //Pin for Backlight

#define LCD_DB4                        PC2          //Pin for D4 (Data, Bit 4)
#define LCD_DB5                        PC3          //Pin for D5 (Data, Bit 5)
#define LCD_DB6                        PC4          //Pin for D6 (Data, Bit 6)
#define LCD_DB7                        PC5          //Pin for D7 (Data, Bit 7)


//GLCD
#define GLCD_CTRL_PORT               PORTB          //Controller Port for LCD Output
#define GLCD_CTRL_DDR                 DDRB          //DDR Register of Controller Port for LCD Output
#define GLCD_DI                        PB2          //Pin for DI (Data/Instruction)
#define GLCD_RW                        PB3          //Pin for R/W (Read/Write)
#define GLCD_EN                        PB4          //Pin for E (Enable)
#define GLCD_CS1                       PB5          //Pin for CS1 (Chip 1 Select, Column 1-64)
#define GLCD_CS2                       PB6          //Pin for CS2 (Chip 2 Select, Column 65-128)
#define GLCD_RST                       PB7          //Pin for RST (RESET)

#define GLCD_ADDR_PORT               PORTC          //Address Port for GLCD Output
#define GLCD_ADDR_DDR                 DDRC          //DDR Register of Address Port for GLCD Output
#define GLCD_DB0                       PC0          //Pin for D4 (Data, Bit 4)
#define GLCD_DB1                       PC1          //Pin for D5 (Data, Bit 5)
#define GLCD_DB2                       PC2          //Pin for D6 (Data, Bit 6)
#define GLCD_DB3                       PC3          //Pin for D7 (Data, Bit 7)
#define GLCD_DB4                       PC4          //Pin for D4 (Data, Bit 4)
#define GLCD_DB5                       PC5          //Pin for D5 (Data, Bit 5)
#define GLCD_DB6                       PC6          //Pin for D6 (Data, Bit 6)
#define GLCD_DB7                       PC7          //Pin for D7 (Data, Bit 7)


//GLCD (latched I/O)
//GLCD
#define GLCD_L_PORT                  PORTC          //Controller Port for LCD Output
#define GLCD_L_DDR                    DDRC          //DDR Register of Controller Port for LCD Output
#define GLCD_L_DI                      PC0          //Pin for DI (Data/Instruction)
//#define GLCD_L_RW                      PB3          //Pin for R/W (Read/Write) [NOT USED FOR LATCHED I/O!]
#define GLCD_L_EN                      PC7          //Pin for E (Enable)
#define GLCD_L_CS1                     PC1          //Pin for CS1 (Chip 1 Select, Column 1-64)
#define GLCD_L_CS2                     PC2          //Pin for CS2 (Chip 2 Select, Column 65-128)
#define GLCD_L_RST                     PC6          //Pin for RST (RESET)
#define GLCD_L_LATCH1_ENABLE           PC4          //Pin for Latch Enable (Latch 1)
#define GLCD_L_LATCH2_ENABLE           PC5          //Pin for Latch Enable (Latch 2)
#define GLCD_L_DB0                     PC0          //Pin for D0 (Data, Bit 0)
#define GLCD_L_DB1                     PC1          //Pin for D1 (Data, Bit 1)
#define GLCD_L_DB2                     PC2          //Pin for D2 (Data, Bit 2)
#define GLCD_L_DB3                     PC3          //Pin for D3 (Data, Bit 3)
#define GLCD_L_DB4                     PC0          //Pin for D4 (Data, Bit 4)
#define GLCD_L_DB5                     PC1          //Pin for D5 (Data, Bit 5)
#define GLCD_L_DB6                     PC2          //Pin for D6 (Data, Bit 6)
#define GLCD_L_DB7                     PC3          //Pin for D7 (Data, Bit 7)



//LED
#define LED_PORT                     PORTD
#define LED_DDR                       DDRD
#define LED_ADDR0                      PD7

//Buzzer
#define BUZ_PORT                     PORTD
#define BUZ_DDR                       DDRD
#define BUZ_ADDR0                      PD5


//Buttons
#define BUT_PORT                     PORTD
#define BUT_DDR                       DDRD
#define BUT_PIN                       PIND
#define BUT_ADDR                       PD6


//A/D Conversion
#define ADC_PORT                     PORTA           //PORTx of Port which is connected to A/D converter (e.g. Port A of ATmega16)
#define ADC_DDR                       DDRA           //DDR of Port which is connected to A/D converter (e.g. Port A of ATmega16)
#define ADC_PIN                        PA6           //used input pin for A/D conversion


//CAN Controller
#define CAN_ADDR_PORT                PORTC           //Port for CAN Address Bus (SJA1000 Address Bus)
#define CAN_ADDR_PIN                  PINC           //Input Port Registers for CAN Address Bus (SJA1000 Address Bus)
#define CAN_ADDR_DDR                  DDRC           //DDR of Port for CAN Address Bus (SJA1000 Address Bus)
#define CAN_ADDR0                      PC0           //PIN0 of CAN Address (SJA1000 Address Bus)
#define CAN_ADDR1                      PC1           //PIN1 of CAN Address (SJA1000 Address Bus)
#define CAN_ADDR2                      PC2           //PIN2 of CAN Address (SJA1000 Address Bus)
#define CAN_ADDR3                      PC3           //PIN3 of CAN Address (SJA1000 Address Bus)
#define CAN_ADDR4                      PC4           //PIN4 of CAN Address (SJA1000 Address Bus)
#define CAN_ADDR5                      PC5           //PIN5 of CAN Address (SJA1000 Address Bus)
#define CAN_ADDR6                      PC6           //PIN6 of CAN Address (SJA1000 Address Bus)
#define CAN_ADDR7                      PC7           //PIN7 of CAN Address (SJA1000 Address Bus)

#define CAN_CTRL_PORT                PORTB           //Port for CAN Control Signals (SJA1000 Bus)
#define CAN_CTRL_DDR                  DDRB           //DDR of Port for CAN Control Signals (SJA1000 Bus)
#define CAN_CTRL_CS                    PB0           //Chip Select Signal for SJA1000 (Output)
#define CAN_CTRL_RST                   PB1           //Reset Signal for SJA1000 (Output)
#define CAN_CTRL_INT                   PB2           //INT Signal for SJA1000 (Input)
#define CAN_CTRL_RDE                   PB3           //RD/E Signal for SJA1000 (Output)
#define CAN_CTRL_WR                    PB4           //WR Signal for SJA1000 (Output)
#define CAN_CTRL_ALE                   PB5           //ALE Signal for SJA1000 (Output)


//RFM12 Wireless Module
#define RFM12_PORT                   PORTB          //Port for RFM12 Module
#define RFM12_PIN                     PINB          //PIN for RFM12 Module
#define RFM12_DDR                     DDRB          //DDR Register of Port for RFM12 Module
#define RFM12_LEDG                     PB0          //LED (green) for receiving messages indication
#define RFM12_LEDY                     PB1          //LED (yellow) for sending messages indication
#define RFM12_nIRQ                     PB2          //Interrupt Signal from RFM12 (low active)
#define RFM12_nRES                     PB3          //Reset Signal to RFM12 (low active)
#define RFM12_nSEL                     PB4          //Slave Select Signal to RFM12 (low active)
#define RFM12_SDI                      PB5          //Slave Data Input Signal (MOSI) to RFM12
#define RFM12_SDO                      PB6          //Slave Data Output Signal (MISO) from RFM12
#define RFM12_SCK                      PB7          //Clock Signal to RFM12




#endif // PORT_DEFINITIONS_H_INCLUDED
