//!/////////////////////////////////////////////////////////////////////////
/// rfm12_io.h                                                            //
///                                                                       //
/// Version:     0.2                                                      //
/// Date:        07/01/2010                                               //
/// Author:      Michael Skutek (michael@skutek.de)                       //
///                                                                       //
/// Description: SPI Interface to RFM2 wireless module                    //
///                                                                       //
/// Platform:    AVR ATmega (tested on ATmega16)                          //
///                                                                       //
/// Include Files:                                                        //
///              avr/io.h:             port accessing (part of avr-gcc)   //
///              util/delay.h:         time delays (part of avr-gcc)      //
///              port_definitions.h:   definition of output ports         //
///              rfm12_io.h:           definitions for RFM12_io           //
///                                                                       //
///                                                                       //
/// This program is free software: you can redistribute it and/or modify  //
/// it under the terms of the GNU Lesser General Public License as        //
/// published by the Free Software Foundation, either version 3 of the    //
/// License, or (at your option) any later version.                       //
///                                                                       //
/// This program is distributed in the hope that it will be useful,       //
/// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          //
/// GNU Lesser General Public License for more details.                   //
///                                                                       //
/// You should have received a copy of the GNU Lesser General Public      //
/// License along with this program. If not, see                          //
/// <http://www.gnu.org/licenses/>.                                       //
//!/////////////////////////////////////////////////////////////////////////


#ifndef RFM12_IO_H_INCLUDED
#define RFM12_IO_H_INCLUDED




///timing definitions

#define RFM12_POR_DELAY_MS                 200        //Power-On Reset [ms]
#define RFM12_RESET_WIDTH_MS               200        //Reset Pulse Width [ms]


///definitions for values

#define RFM12_REGISTER_DATA                0x1        //data i/o: register data
#define RFM12_TX_DATA                      0x2        //data i/o: transmit data
#define RFM12_RX_DATA                      0x3        //data i/o: receive data


#define RFM12_TRANSMISSION_BURST             1        //burst during transmission enabled [1] or not [0]
                                                      //during data transmission nSEL will be hold at "Low"

#define RFM12_CONFIG_VALUE              0x80e7        //Configuration Setting Value: EL; EF; 868 MHz; 11,5 pF
#define RFM12_POWERMANAGEMENT_TX_VALUE  0x8239        //Power Management Value: ET; ES; EX; DC
#define RFM12_POWERMANAGEMENT_RX_VALUE  0x82c9        //Power Management Value: ER; EBB; ES; EX; DC
#define RFM12_POWERSETTING_VALUE        0x94cd        //Power Setting Value: VDI; Fast; 67 kHz; -6 dB; -71 dB
#define RFM12_STATUSREAD_VALUE          0x0000        //Status Read Command
#define RFM12_FREQUENCY_VALUE           0xa6a4        //Frequency Setting Command: 868,5 MHz
#define RFM12_DATARATE_VALUE            0xc611        //Data Rate Setting Command: 19200 bps
#define RFM12_DATAFILTER_VALUE          0xc2ab        //Data Filter Command: AL, Digital Filter, Treshold: 4
#define RFM12_FIFOMODE_VALUE            0xca83        //FIFO Mode Command: FIFO IT Level: 8, ff, dr
#define RFM12_NOFIFOMODE_VALUE          0xca81        //FIFO Mode Command: FIFO IT Level: 8, dr
#define RFM12_AFC_VALUE                 0xc4f7        //AFC Command: only receiving; +3/-4; FI; OE; EN
#define RFM12_TXCONFIG_VALUE            0x9822        //TX Configuration Setting Value: 45 kHz; -5 dB
//#define RFM12_TXCONFIG_VALUE            0x9820        //TX Configuration Setting Value: 45 kHz; -0 dB
#define RFM12_PLLSETTING_VALUE          0xcc77        //PLL Setting Value: 30 kHz; -9 dB
#define RFM12_WAKEUPTIMER_VALUE         0xE000        //Wakeup Timer Setting Value: not used
#define RFM12_LOWDUTYCYCLE_VALUE        0xc800        //Low Duty-Cycle Setting Value: not used
#define RFM12_LOWBATDET_VALUE           0xc000        //Low Battery Detector Value: 2,25 V; 1 MHz
#define RFM12_FIFOREAD_VALUE            0xb000        //Read RX FIFO Command (High Byte)
#define RFM12_SYNCHRONPATTERN_VALUE     0xced4        //Synchron Pattern Command (only for SI4421)



///function definitions

uint8_t rfm12_data_io(volatile uint16_t *, volatile uint16_t *, uint8_t, uint8_t);
uint16_t rfm12_init(void);
void rfm12_pin_init(void);





#endif // RFM12_IO_H_INCLUDED
